Structs
- Cache
Key - Cache key for the renderer’s glyph slug cache -> uniquely identifies a specific glyph in a specific font face.
- Glyph
Bitmap - Glyph
Key - Shaped
Glyph - Text
Metrics
Enums
- Command
- Vector path command for glyph outlines.
- Swash
Content - Content of a scaled glyph image.
Statics
Functions
- begin_
frame - current_
frame - ellipsize_
line - extract_
outline_ commands - font_
family_ name - Extract the family name from raw font bytes.
- load_
font_ file - Load a font from a file path and register it into the global font system.
- lookup_
and_ extract_ outline - lookup_
cache_ key - metrics_
for_ textfield - rasterize
- register_
font_ data - shape_
line - wrap_
line_ ranges - wrap_
lines