load_font_file

Function load_font_file 

pub fn load_font_file(path: impl AsRef<Path>) -> Result<()>
Load a font from a file path and register it into the global font system.

Returns an error if the file cannot be read.