Crate repose_text

Crate repose_text 

Structs

CacheKey
Cache key for the renderer’s glyph slug cache — uniquely identifies a specific glyph in a specific font face.
GlyphBitmap
GlyphKey
ShapedGlyph
TextMetrics

Enums

Command
Vector path command for glyph outlines.
SwashContent
Content of a scaled glyph image.

Statics

FONT_PROVIDER

Functions

begin_frame
current_frame
ellipsize_line
extract_outline_commands
font_family_name
Extract the family name from raw font bytes.
load_font_file
Load a font from a file path and register it into the global font system.
lookup_and_extract_outline
lookup_cache_key
metrics_for_textfield
rasterize
register_font_data
shape_line
wrap_line_ranges
wrap_lines